@@ -10,28 +10,35 @@ import sys
 import os
 
 # Global log handler
-log = logging.getLogger('wpwatcher')
+log = logging.getLogger("wpwatcher")
 
 # Setup global stdout logger
 def init_log(verbose=False, quiet=False, logfile=None, nostd=False):
-    format_string='%(asctime)s - %(levelname)s - %(message)s'
-    format_string_cli='%(levelname)s - %(message)s'
-    if verbose : verb_level=logging.DEBUG
-    elif quiet : verb_level=logging.ERROR
-    else : verb_level=logging.INFO
+    format_string = "%(asctime)s - %(levelname)s - %(message)s"
+    format_string_cli = "%(levelname)s - %(message)s"
+    if verbose:
+        verb_level = logging.DEBUG
+    elif quiet:
+        verb_level = logging.ERROR
+    else:
+        verb_level = logging.INFO
     # Add stdout: configurable
     log.setLevel(verb_level)
     std = logging.StreamHandler(sys.stdout)
     std.setLevel(verb_level)
     std.setFormatter(logging.Formatter(format_string_cli))
-    log.handlers=[]
-    if not nostd: log.addHandler(std)
-    else: log.addHandler(logging.StreamHandler(open(os.devnull,'w')))
-    if logfile :
+    log.handlers = []
+    if not nostd:
+        log.addHandler(std)
+    else:
+        log.addHandler(logging.StreamHandler(open(os.devnull, "w")))
+    if logfile:
         fh = logging.FileHandler(logfile)
         fh.setLevel(verb_level)
         fh.setFormatter(logging.Formatter(format_string))
         log.addHandler(fh)
-    if verbose and quiet :
-        log.info("Verbose and quiet values are both set to True. By default, verbose value has priority.")
-    return (log)
\ No newline at end of file
+    if verbose and quiet:
+        log.info(
+            "Verbose and quiet values are both set to True. By default, verbose value has priority."
+        )
+    return log
